CodePrinter -> AsmPrinter


git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@15599 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/lib/Target/PowerPC/PPCAsmPrinter.cpp b/lib/Target/PowerPC/PPCAsmPrinter.cpp
index 62deac0..8f41683 100644
--- a/lib/Target/PowerPC/PPCAsmPrinter.cpp
+++ b/lib/Target/PowerPC/PPCAsmPrinter.cpp
@@ -85,12 +85,12 @@
   };
 } // end of anonymous namespace
 
 /// createPPCCodePrinterPass - Returns a pass that prints the PPC
 /// assembly code for a MachineFunction to the given output stream,
 /// using the given target machine description.  This should work
-/// regardless of whether the function is in SSA form.
+/// regardless of whether the function is in SSA form or not.
 ///
-FunctionPass *createPPCCodePrinterPass(std::ostream &o,TargetMachine &tm) {
+FunctionPass *createPPCAsmPrinterPass(std::ostream &o,TargetMachine &tm) {
   return new Printer(o, tm);
 }
@@ -85,12 +85,12 @@
 } // end of anonymous namespace
 
-/// createPPCCodePrinterPass - Returns a pass that prints the PPC
+/// createPPCAsmPrinterPass - Returns a pass that prints the PPC
 /// assembly code for a MachineFunction to the given output stream,
 /// using the given target machine description.  This should work